==> code_saturne-8.1.1-3-x86_64.pkg.tar.zst: usr/share/doc/code_saturne/doxygen/src/cs__renumber_8h.js <==
var cs__renumber_8h =
[
    [ "cs_renumber_b_faces_type_t", "cs__renumber_8h.html#a93348d7f471751c26573745b9c6b810b", [
      [ "CS_RENUMBER_B_FACES_THREAD", "cs__renumber_8h.html#a93348d7f471751c26573745b9c6b810ba13bb766b9a0a03ef9e996555310e8384", null ],
      [ "CS_RENUMBER_B_FACES_SIMD", "cs__renumber_8h.html#a93348d7f471751c26573745b9c6b810baeeec36274b8db1f482683d4e333c5641", null ],
      [ "CS_RENUMBER_B_FACES_NONE", "cs__renumber_8h.html#a93348d7f471751c26573745b9c6b810baca8375a8c0b1aed83f9ccd8c25f04e18", null ]
    ] ],
    [ "cs_renumber_cells_type_t", "cs__renumber_8h.html#a6ebe24c8101714898c4ccaceabfdb5e0", [
      [ "CS_RENUMBER_CELLS_SCOTCH_PART", "cs__renumber_8h.html#a6ebe24c8101714898c4ccaceabfdb5e0a44095fff4551efa096333cda47b96ef4", null ],
      [ "CS_RENUMBER_CELLS_SCOTCH_ORDER", "cs__renumber_8h.html#a6ebe24c8101714898c4ccaceabfdb5e0ae3b6bf9e84e9532364399eada7f0175a", null ],
      [ "CS_RENUMBER_CELLS_METIS_PART", "cs__renumber_8h.html#a6ebe24c8101714898c4ccaceabfdb5e0a42c460b653877b47db39750bfd9b4516", null ],
      [ "CS_RENUMBER_CELLS_METIS_ORDER", "cs__renumber_8h.html#a6ebe24c8101714898c4ccaceabfdb5e0aacd8526211d5afa79e1b027b1d2ab013", null ],
      [ "CS_RENUMBER_CELLS_MORTON", "cs__renumber_8h.html#a6ebe24c8101714898c4ccaceabfdb5e0a6180e2175a3db36bcf7bb3bd16bee535", null ],
      [ "CS_RENUMBER_CELLS_HILBERT", "cs__renumber_8h.html#a6ebe24c8101714898c4ccaceabfdb5e0ac09250da6db57467764b84ccc515b57f", null ],
      [ "CS_RENUMBER_CELLS_RCM", "cs__renumber_8h.html#a6ebe24c8101714898c4ccaceabfdb5e0a4b19b928055a70bb51a0ae759f88d501", null ],
      [ "CS_RENUMBER_CELLS_NONE", "cs__renumber_8h.html#a6ebe24c8101714898c4ccaceabfdb5e0a566c325761cd83e814995d322754de7a", null ]
    ] ],
    [ "cs_renumber_i_faces_type_t", "cs__renumber_8h.html#a3f9a34223e8796217aee690d9e20c225", [
      [ "CS_RENUMBER_I_FACES_BLOCK", "cs__renumber_8h.html#a3f9a34223e8796217aee690d9e20c225a2f879e2deca04266ffc451600f4bd7ee", null ],
      [ "CS_RENUMBER_I_FACES_MULTIPASS", "cs__renumber_8h.html#a3f9a34223e8796217aee690d9e20c225a1e6b2b9ecfa80af9c0ba1563ec1cd6d3", null ],
      [ "CS_RENUMBER_I_FACES_SIMD", "cs__renumber_8h.html#a3f9a34223e8796217aee690d9e20c225a2bf6cb0398953fff40da20fe0a40ec0e", null ],
      [ "CS_RENUMBER_I_FACES_NONE", "cs__renumber_8h.html#a3f9a34223e8796217aee690d9e20c225a8d78e9f4e08a4608f248555a6f797e73", null ]
    ] ],
    [ "cs_renumber_ordering_t", "cs__renumber_8h.html#a601467465d8b436fb5bbd6e634910f0b", [
      [ "CS_RENUMBER_ADJACENT_LOW", "cs__renumber_8h.html#a601467465d8b436fb5bbd6e634910f0ba052915e0ee7e064ac89725cf752524fe", null ],
      [ "CS_RENUMBER_ADJACENT_HIGH", "cs__renumber_8h.html#a601467465d8b436fb5bbd6e634910f0ba6aee9f0eedbd33ad455722c63771d74f", null ]
    ] ],
    [ "cs_renumber_vertices_type_t", "cs__renumber_8h.html#a72445c49c82c93caea1b71b2758b13a1", [
      [ "CS_RENUMBER_VERTICES_BY_CELL_ADJ", "cs__renumber_8h.html#a72445c49c82c93caea1b71b2758b13a1a4026ab05d1ae2f781eeacf4685af2128", null ],
      [ "CS_RENUMBER_VERTICES_BY_FACE_ADJ", "cs__renumber_8h.html#a72445c49c82c93caea1b71b2758b13a1a1de30c78be5f2503eca69fbf0346d05a", null ],
      [ "CS_RENUMBER_VERTICES_NONE", "cs__renumber_8h.html#a72445c49c82c93caea1b71b2758b13a1ac9ea96f0fe8776909969407940c897cb", null ]
    ] ],
    [ "cs_renumber_b_faces", "cs__renumber_8h.html#a1c1a6ea35bc209bae71f97bcac91bae8", null ],
    [ "cs_renumber_b_faces_by_gnum", "cs__renumber_8h.html#aaa36f674b7f1e9e22ee7110f4f55246c", null ],
    [ "cs_renumber_b_faces_select_ignore", "cs__renumber_8h.html#a43659b0224bd76d9f30f3b1d5e5511bd", null ],
    [ "cs_renumber_cells", "cs__renumber_8h.html#ab7c7c766f2c98f1cb966e73875858084", null ],
    [ "cs_renumber_get_algorithm", "cs__renumber_8h.html#ae2f997159ace0fcb717fb8d3048ce1f4", null ],
    [ "cs_renumber_get_min_subset_size", "cs__renumber_8h.html#a0892232b15dbdb68223cc539fc75ac1e", null ],
    [ "cs_renumber_get_n_threads", "cs__renumber_8h.html#af021c347d7ce0a70bd83bd74206f74fa", null ],
    [ "cs_renumber_i_faces", "cs__renumber_8h.html#af7896bb1689973fd82a8515b65950bae", null ],
    [ "cs_renumber_i_faces_by_gnum", "cs__renumber_8h.html#a5a3d536a6a4622f991c58faead7f61e5", null ],
    [ "cs_renumber_mesh", "cs__renumber_8h.html#a042fd73b254608b5e305cca20e7553aa", null ],
    [ "cs_renumber_set_algorithm", "cs__renumber_8h.html#a4003a04330722a4795d7cbb768501115", null ],
    [ "cs_renumber_set_min_subset_size", "cs__renumber_8h.html#ae45660359beaa62cd595dff91d045ab6", null ],
    [ "cs_renumber_set_n_threads", "cs__renumber_8h.html#a14067a3ababe5dc70ed7c4c1af4189db", null ],
    [ "cs_renumber_vertices", "cs__renumber_8h.html#af1700f81a93e591a9bda28b134b5f985", null ]
];

==> code_saturne-9.1.0-1-x86_64.pkg.tar.zst: usr/share/doc/code_saturne/doxygen/src/cs__renumber_8h.js <==
var cs__renumber_8h =
[
    [ "cs_renumber_b_faces_type_t", "cs__renumber_8h.html#a93348d7f471751c26573745b9c6b810b", [
      [ "CS_RENUMBER_B_FACES_THREAD", "cs__renumber_8h.html#a93348d7f471751c26573745b9c6b810ba13bb766b9a0a03ef9e996555310e8384", null ],
      [ "CS_RENUMBER_B_FACES_SIMD", "cs__renumber_8h.html#a93348d7f471751c26573745b9c6b810baeeec36274b8db1f482683d4e333c5641", null ],
      [ "CS_RENUMBER_B_FACES_NONE", "cs__renumber_8h.html#a93348d7f471751c26573745b9c6b810baca8375a8c0b1aed83f9ccd8c25f04e18", null ]
    ] ],
    [ "cs_renumber_cells_type_t", "cs__renumber_8h.html#a6ebe24c8101714898c4ccaceabfdb5e0", [
      [ "CS_RENUMBER_CELLS_SCOTCH_PART", "cs__renumber_8h.html#a6ebe24c8101714898c4ccaceabfdb5e0a44095fff4551efa096333cda47b96ef4", null ],
      [ "CS_RENUMBER_CELLS_SCOTCH_ORDER", "cs__renumber_8h.html#a6ebe24c8101714898c4ccaceabfdb5e0ae3b6bf9e84e9532364399eada7f0175a", null ],
      [ "CS_RENUMBER_CELLS_METIS_PART", "cs__renumber_8h.html#a6ebe24c8101714898c4ccaceabfdb5e0a42c460b653877b47db39750bfd9b4516", null ],
      [ "CS_RENUMBER_CELLS_METIS_ORDER", "cs__renumber_8h.html#a6ebe24c8101714898c4ccaceabfdb5e0aacd8526211d5afa79e1b027b1d2ab013", null ],
      [ "CS_RENUMBER_CELLS_MORTON", "cs__renumber_8h.html#a6ebe24c8101714898c4ccaceabfdb5e0a6180e2175a3db36bcf7bb3bd16bee535", null ],
      [ "CS_RENUMBER_CELLS_HILBERT", "cs__renumber_8h.html#a6ebe24c8101714898c4ccaceabfdb5e0ac09250da6db57467764b84ccc515b57f", null ],
      [ "CS_RENUMBER_CELLS_RCM", "cs__renumber_8h.html#a6ebe24c8101714898c4ccaceabfdb5e0a4b19b928055a70bb51a0ae759f88d501", null ],
      [ "CS_RENUMBER_CELLS_NONE", "cs__renumber_8h.html#a6ebe24c8101714898c4ccaceabfdb5e0a566c325761cd83e814995d322754de7a", null ]
    ] ],
    [ "cs_renumber_i_faces_type_t", "cs__renumber_8h.html#a3f9a34223e8796217aee690d9e20c225", [
      [ "CS_RENUMBER_I_FACES_BLOCK", "cs__renumber_8h.html#a3f9a34223e8796217aee690d9e20c225a2f879e2deca04266ffc451600f4bd7ee", null ],
      [ "CS_RENUMBER_I_FACES_MULTIPASS", "cs__renumber_8h.html#a3f9a34223e8796217aee690d9e20c225a1e6b2b9ecfa80af9c0ba1563ec1cd6d3", null ],
      [ "CS_RENUMBER_I_FACES_SIMD", "cs__renumber_8h.html#a3f9a34223e8796217aee690d9e20c225a2bf6cb0398953fff40da20fe0a40ec0e", null ],
      [ "CS_RENUMBER_I_FACES_NONE", "cs__renumber_8h.html#a3f9a34223e8796217aee690d9e20c225a8d78e9f4e08a4608f248555a6f797e73", null ]
    ] ],
    [ "cs_renumber_ordering_t", "cs__renumber_8h.html#a601467465d8b436fb5bbd6e634910f0b", [
      [ "CS_RENUMBER_ADJACENT_LOW", "cs__renumber_8h.html#a601467465d8b436fb5bbd6e634910f0ba052915e0ee7e064ac89725cf752524fe", null ],
      [ "CS_RENUMBER_ADJACENT_HIGH", "cs__renumber_8h.html#a601467465d8b436fb5bbd6e634910f0ba6aee9f0eedbd33ad455722c63771d74f", null ]
    ] ],
    [ "cs_renumber_vertices_type_t", "cs__renumber_8h.html#a72445c49c82c93caea1b71b2758b13a1", [
      [ "CS_RENUMBER_VERTICES_BY_CELL_ADJ", "cs__renumber_8h.html#a72445c49c82c93caea1b71b2758b13a1a4026ab05d1ae2f781eeacf4685af2128", null ],
      [ "CS_RENUMBER_VERTICES_BY_FACE_ADJ", "cs__renumber_8h.html#a72445c49c82c93caea1b71b2758b13a1a1de30c78be5f2503eca69fbf0346d05a", null ],
      [ "CS_RENUMBER_VERTICES_NONE", "cs__renumber_8h.html#a72445c49c82c93caea1b71b2758b13a1ac9ea96f0fe8776909969407940c897cb", null ]
    ] ],
    [ "cs_renumber_b_faces", "cs__renumber_8h.html#a1c1a6ea35bc209bae71f97bcac91bae8", null ],
    [ "cs_renumber_b_faces_by_gnum", "cs__renumber_8h.html#aaa36f674b7f1e9e22ee7110f4f55246c", null ],
    [ "cs_renumber_b_faces_select_ignore", "cs__renumber_8h.html#a43659b0224bd76d9f30f3b1d5e5511bd", null ],
    [ "cs_renumber_cells", "cs__renumber_8h.html#ab7c7c766f2c98f1cb966e73875858084", null ],
    [ "cs_renumber_get_algorithm", "cs__renumber_8h.html#ae2f997159ace0fcb717fb8d3048ce1f4", null ],
    [ "cs_renumber_get_min_subset_size", "cs__renumber_8h.html#a0892232b15dbdb68223cc539fc75ac1e", null ],
    [ "cs_renumber_get_multipass_rebalance_factor", "cs__renumber_8h.html#a837652abfcf83dccce8534bf64b54ac4", null ],
    [ "cs_renumber_get_n_threads", "cs__renumber_8h.html#af021c347d7ce0a70bd83bd74206f74fa", null ],
    [ "cs_renumber_i_faces", "cs__renumber_8h.html#af7896bb1689973fd82a8515b65950bae", null ],
    [ "cs_renumber_i_faces_by_gnum", "cs__renumber_8h.html#a5a3d536a6a4622f991c58faead7f61e5", null ],
    [ "cs_renumber_mesh", "cs__renumber_8h.html#a042fd73b254608b5e305cca20e7553aa", null ],
    [ "cs_renumber_set_algorithm", "cs__renumber_8h.html#a4003a04330722a4795d7cbb768501115", null ],
    [ "cs_renumber_set_min_subset_size", "cs__renumber_8h.html#ae45660359beaa62cd595dff91d045ab6", null ],
    [ "cs_renumber_set_multipass_rebalance_factor", "cs__renumber_8h.html#a57c78c7935aefb2f903f200ed3f92889", null ],
    [ "cs_renumber_set_n_threads", "cs__renumber_8h.html#a14067a3ababe5dc70ed7c4c1af4189db", null ],
    [ "cs_renumber_vertices", "cs__renumber_8h.html#af1700f81a93e591a9bda28b134b5f985", null ]
];
